(function() {
  var Attachments;

  Attachments = (function() {
    function Attachments(attachmentTag, type, options) {
      var ref, ref1, ref2;
      if (options == null) {
        options = {};
      }
      this.filename = null;
      this.filesize = null;
      this.attachmentDiv = null;
      this.hasDownloaded = false;
      this.isDownloaded = false;
      this.inProgress = false;
      this.mbURL = null;
      this.fileSizeDisplayLimit = (ref = options.fileSizeDisplayLimit) != null ? ref : 1024 * 1024 * 4;
      this.attachmentDownloadIcon = typeof attachmentDownloadIcon !== "undefined" && attachmentDownloadIcon !== null ? attachmentDownloadIcon : '';
      this.attachmentPauseIcon = typeof attachmentPauseIcon !== "undefined" && attachmentPauseIcon !== null ? attachmentPauseIcon : '';
      this.attachmentProgressIcon = typeof attachmentProgressIcon !== "undefined" && attachmentProgressIcon !== null ? attachmentProgressIcon : '';
      this.attachmentRetryIcon = typeof attachmentRetryIcon !== "undefined" && attachmentRetryIcon !== null ? attachmentRetryIcon : '';
      this.redownloadDelay = (ref1 = options.redownloadDelay) != null ? ref1 : 3000;
      this.redownloadAttempts = (ref2 = options.redownloadAttempt) != null ? ref2 : 3;
      this.redownloadRetryCount = 0;
      this.downloadError = false;
      if (attachmentTag != null) {
        this.attachmentDiv = this._processMBAttachmentTag(attachmentTag);
        this.setProgress(0);
      } else {
        throw new Error("Attachment tag needed");
      }
      return this;
    }

    Attachments.linkHelper = function(link) {
      return typeof bridge !== "undefined" && bridge !== null ? typeof bridge.handleMailboxRequest === "function" ? bridge.handleMailboxRequest(link) : void 0 : void 0;
    };

    Attachments.deselectAll = function() {
      var active, actives, j, len, results;
      actives = document.querySelectorAll('.mbx-active');
      results = [];
      for (j = 0, len = actives.length; j < len; j++) {
        active = actives[j];
        results.push(active.classList.remove('mbx-active'));
      }
      return results;
    };

    Attachments.prototype.select = function() {
      if (this.hasDownloaded) {
        this.attachmentDiv.classList.add('mbx-active');
      }
      return this;
    };

    Attachments.prototype.deselect = function() {
      this.attachmentDiv.classList.remove('mbx-active');
      return this;
    };

    Attachments.prototype.setProgress = function(progress) {
      var el, fillElements, fill_rotation, fixElements, fix_rotation, inverse_progress, j, k, len, len1, rotation;
      if (progress > 100) {
        progress = 100;
      }
      if (progress < 0) {
        progress = 0;
      }
      inverse_progress = Math.abs(100 - progress);
      rotation = Math.floor(1.8 * inverse_progress);
      fill_rotation = rotation;
      fix_rotation = rotation * 2;
      fillElements = this.attachmentDiv.querySelectorAll('.mbx-circle .mbx-fill, .mbx-circle .mbx-mask.mbx-full');
      fixElements = this.attachmentDiv.querySelectorAll('.mbx-circle .mbx-fill.mbx-fix');
      for (j = 0, len = fillElements.length; j < len; j++) {
        el = fillElements[j];
        el.style.webkitTransform = "rotate(" + fill_rotation + "deg)";
      }
      for (k = 0, len1 = fixElements.length; k < len1; k++) {
        el = fixElements[k];
        el.style.webkitTransform = "rotate(" + fix_rotation + "deg)";
      }
    };

    Attachments.prototype.resetDownloadState = function() {
      this._updateFileSize(this._bytesToSize(this.filesize));
      this.setAttachmentReadyState(false);
      return this;
    };

    Attachments.prototype.downloadFailed = function() {
      this._updateFileSize('File not found', true);
      this.downloadError = true;
      return this.setAttachmentReadyState(false);
    };

    Attachments.prototype.mailboxURLAction = function(action) {
      var mailboxUrl;
      mailboxUrl = this.mbURL;
      if (mailboxUrl != null) {
        mailboxUrl = mailboxUrl.replace("attachment_download", action);
        mailboxUrl = mailboxUrl.replace("check_download", action);
        mailboxUrl = mailboxUrl.replace("s3_download", action);
        mailboxUrl = mailboxUrl.replace("dropbox_download", action);
        mailboxUrl = mailboxUrl.replace("open_file", action);
      }
      return mailboxUrl;
    };

    Attachments.prototype.downloadDone = function(att_id, file_url, optional_image_src, process_video) {
      var img, sizeText, src, video;
      if (optional_image_src == null) {
        optional_image_src = null;
      }
      if (process_video == null) {
        process_video = false;
      }
      if (this.isDownloaded) {
        return;
      }
      this.setAttachmentReadyState(true);
      this.setProgress(100);
      this._displayProgress(false);
      src = file_url;
      if (optional_image_src != null) {
        src = optional_image_src;
      }
      if (this.shouldShowDownloadedImage()) {
        img = document.createElement('img');
        img.setAttribute('name', "mailbox-att" + att_id);
        img.setAttribute('data-fileurl', file_url);
        img.setAttribute('class', 'orc-inline-image');
        img.setAttribute('src', src);
        this.attachmentDiv.parentNode.replaceChild(img, this.attachmentDiv);
        this.attachmentDiv = img;
      } else if (this._isVideo() && process_video) {
        video = document.createElement('video');
        video.setAttribute('name', "mailbox-att" + att_id);
        video.setAttribute('data-fileurl', file_url);
        video.setAttribute('class', 'orc-inline-video');
        video.setAttribute('src', src);
        this.attachmentDiv.parentNode.replaceChild(video, this.attachmentDiv);
        this.attachmentDiv = video;
      } else {
        sizeText = this._bytesToSize(parseInt(this.filesize));
        this._updateFileSize(sizeText);
        if (this.attachmentDiv.parentNode.tagName === 'A') {
          this.attachmentDiv.parentNode.src = "mailbox://open_file/" + file_url;
          this._updateAttachmentIcon(this.attachmentDownloadIcon);
        }
      }
      return this;
    };

    Attachments.prototype.setAttachmentReadyState = function(state) {
      if (state == null) {
        state = false;
      }
      if (state) {
        this.hasDownloaded = true;
        this.isDownloaded = true;
        this.inProgress = false;
        this._updateAttachmentIcon(this.attachmentDownloadIcon);
      } else {
        this.hasDownloaded = false;
        this.isDownloaded = false;
        this.inProgress = false;
        this._updateAttachmentIcon(this.attachmentRetryIcon);
        this._displayProgress(false);
      }
      return this;
    };

    Attachments.prototype.updateDownloadState = function(val) {
      var currSize, el, pct, sizeText, totalSize;
      el = this.attachmentDiv.getElementsByClassName("mbx-radial-progress")[0];
      if (el.style.display === 'none') {
        this._displayProgress(true);
      }
      this.inProgress = true;
      val = Math.min(this.filesize, val);
      totalSize = this._bytesToSize(parseInt(this.filesize));
      currSize = this._bytesToSize(parseInt(val));
      pct = Math.ceil(parseInt(val) / parseInt(this.filesize) * 100);
      sizeText = pct + "% of " + this.filesizetxt;
      this._updateFileSize(sizeText);
      this.setProgress(pct);
      return this;
    };

    Attachments.prototype.isInlineOrAttachedImage = function() {
      return this._isInlineOrAttachedImage();
    };

    Attachments.prototype.shouldShowDownloadedImage = function() {
      return this._isInlineOrAttachedImage() && parseInt(this.filesize) < parseInt(this.fileSizeDisplayLimit);
    };


    /* Private */

    Attachments.prototype._processMBAttachmentTag = function(tag) {
      var attachmentDiv, filenametxt, filetypeIcon, id, src;
      this.filename = tag.getAttribute('filename');
      filenametxt = decodeURIComponent(this.filename);
      this.filesize = parseInt(tag.getAttribute('size'));
      this.filesizetxt = this._bytesToSize(this.filesize);
      src = tag.getAttribute('src');
      id = src.substring(src.lastIndexOf("/") + 1);
      filetypeIcon = this._attachmentIcon(tag);
      this.mbURL = src + "/" + filenametxt;
      attachmentDiv = this._createAttachmentDiv(id, filenametxt, filetypeIcon);
      return attachmentDiv;
    };

    Attachments.prototype._createAttachmentDiv = function(id, filenametxt, filetypeIcon) {
      var attachDiv, buttonDiv, circleDiv, fileDiv, fileIconDiv, fileIconImg, fileinfoInfoDiv, filenameInfoDiv, fillDiv, img, maskFullDiv, maskHalfDiv, maskHalfFillDiv, maskHalfFillFixDiv, progressDiv;
      attachDiv = document.createElement('div');
      attachDiv.setAttribute('class', 'mbx-attach');
      attachDiv.setAttribute('name', 'mailbox-att' + id);
      attachDiv.setAttribute('draggable', 'true');
      fileDiv = document.createElement('div');
      fileDiv.setAttribute('class', 'mbx-file');
      buttonDiv = document.createElement('div');
      buttonDiv.setAttribute('class', 'mbx-button');
      fileIconDiv = document.createElement('div');
      fileIconDiv.setAttribute('class', 'mbx-fileIcon');
      fileIconImg = document.createElement('img');
      fileIconImg.setAttribute('src', filetypeIcon);
      fileIconDiv.appendChild(fileIconImg);
      progressDiv = document.createElement('div');
      progressDiv.setAttribute('class', 'mbx-radial-progress');
      circleDiv = document.createElement('div');
      circleDiv.setAttribute('class', 'mbx-circle');
      maskFullDiv = document.createElement('div');
      maskFullDiv.setAttribute('class', 'mbx-mask mbx-full');
      fillDiv = document.createElement('div');
      fillDiv.setAttribute('class', 'mbx-fill');
      maskFullDiv.appendChild(fillDiv);
      circleDiv.appendChild(maskFullDiv);
      maskHalfDiv = document.createElement('div');
      maskHalfDiv.setAttribute('class', 'mbx-mask mbx-half');
      maskHalfFillDiv = document.createElement('div');
      maskHalfFillDiv.setAttribute('class', 'mbx-fill');
      maskHalfFillFixDiv = document.createElement('div');
      maskHalfFillFixDiv.setAttribute('class', 'mbx-fill mbx-fix');
      maskHalfDiv.appendChild(maskHalfFillDiv);
      maskHalfDiv.appendChild(maskHalfFillFixDiv);
      circleDiv.appendChild(maskHalfDiv);
      progressDiv.appendChild(circleDiv);
      fileDiv.appendChild(progressDiv);
      filenameInfoDiv = document.createElement('div');
      filenameInfoDiv.setAttribute('class', 'mbx-filename mbx-info');
      filenameInfoDiv.textContent = filenametxt;
      fileinfoInfoDiv = document.createElement('div');
      fileinfoInfoDiv.setAttribute('class', 'mbx-fileinfo mbx-info');
      fileinfoInfoDiv.textContent = this.filesizetxt;
      attachDiv.appendChild(fileIconDiv);
      img = new Image();
      img.src = this.attachmentRetryIcon;
      buttonDiv.style.backgroundImage = "url(" + img.src + ")";
      attachDiv.appendChild(fileDiv);
      fileDiv.appendChild(buttonDiv);
      attachDiv.appendChild(filenameInfoDiv);
      attachDiv.appendChild(fileinfoInfoDiv);
      return attachDiv;
    };

    Attachments.prototype._updateFileSize = function(str) {
      var fileInfoDiv;
      fileInfoDiv = this.attachmentDiv.getElementsByClassName('mbx-fileinfo')[0];
      return fileInfoDiv.textContent = str;
    };

    Attachments.prototype._updateAttachmentIcon = function(iconbase64String) {
      var buttonDiv, img;
      img = new Image();
      img.src = iconbase64String;
      buttonDiv = this.attachmentDiv.getElementsByClassName('mbx-button')[0];
      buttonDiv.style.backgroundImage = "url(" + img.src + ")";
      return this;
    };

    Attachments.prototype._displayProgress = function(display) {
      var displayType, el;
      if (display == null) {
        display = true;
      }
      el = this.attachmentDiv.getElementsByClassName("mbx-radial-progress")[0];
      if (display) {
        displayType = "block";
      } else {
        displayType = "none";
      }
      el.style.display = displayType;
      return this;
    };

    Attachments.prototype._bytesToSize = function(bytes) {
      var i, sizes;
      sizes = ['Bytes', 'KB', 'MB', 'GB', 'TB'];
      if (bytes === 0) {
        return '0 Bytes';
      }
      i = Math.log(bytes) / Math.log(1024);
      i = i | 0;
      return (bytes / Math.pow(1024, i)).toFixed(1) + ' ' + sizes[i];
    };

    Attachments.prototype._attachmentIcon = function(attachment) {
      var mime, previewURL, url;
      previewURL = attachment.parentNode.getAttribute('data-previewurl');
      url = attachment.parentNode.getAttribute('data-url');
      if ((previewURL == null) || previewURL.length === 0) {
        mime = attachment.getAttribute('mime');
        return typeof bridge !== "undefined" && bridge !== null ? typeof bridge.iconFromMimeType === "function" ? bridge.iconFromMimeType(mime) : void 0 : void 0;
      } else {
        return previewURL;
      }
    };

    Attachments.prototype._isVideo = function() {
      var mime, videoText;
      mime = this._getMimeType();
      videoText = "video";
      return mime.substring(0, videoText.length) === "video";
    };

    Attachments.prototype._isInlineOrAttachedImage = function() {
      var parentNode;
      parentNode = this.attachmentDiv.parentNode;
      return parentNode.nodeName === "MAILBOX-IMG" || this._isImage();
    };

    Attachments.prototype._isImage = function() {
      var fileExt, mime, ref, url;
      mime = this._getMimeType();
      if (mime === "image/gif" || mime === "image/jpeg" || mime === "image/jpg" || mime === "image/png" || mime === "image/tiff") {
        return true;
      }
      url = (ref = this.attachmentDiv.parentNode.getAttribute('data-url')) != null ? ref.toLowerCase() : void 0;
      fileExt = "";
      if (url && url.length > 0) {
        fileExt = url.substring(url.lastIndexOf('.') + 1);
      }
      if (fileExt === 'gif' || fileExt === 'png' || fileExt === 'jpg' || fileExt === 'jpeg' || fileExt === 'tiff') {
        return true;
      }
      return false;
    };

    Attachments.prototype._getMimeType = function() {
      return this.attachmentDiv.parentNode.getAttribute('mime') || '';
    };

    return Attachments;

  })();


  /* export */

  this.Attachments = Attachments;

}).call(this);

var activeAttachment, attachmentClickHandler, attachmentDragEndHandler, attachmentDragHandler, atts, autoDownloadAttachments, convertAttachmentTags, createHeadTagAndViewPortIfNecessary, docReady, downloadAttachment, failedDownloadForAttachment, finishDownloading, handleShowMore, insertFullBody, invalidateContentHeight, keydownHandler, keyupHandler, lastContentHeight, loadingdiv, resetDownloadForAttachment, resetShowMore, updateContentHeight, updateDownloadState, urlForAttachment;

activeAttachment = null;

atts = {};

createHeadTagAndViewPortIfNecessary = function() {
  var headTag, headTags, j, len, viewport, viewportTag, viewportTags;
  headTags = document.getElementsByTagName('head');
  if (headTags.length > 0) {
    headTag = headTags[0];
  } else {
    headTag = document.createElement('head');
    document.insertBefore(headTag, document.firstChild);
  }
  viewportTags = document.getElementsByName('viewport');
  for (j = 0, len = viewportTags.length; j < len; j++) {
    viewportTag = viewportTags[j];
    viewportTag.parentNode.removeChild(viewportTag);
  }
  viewport = document.createElement('meta');
  viewport.setAttribute('id', 'mailbox-viewport');
  viewport.setAttribute('name', 'viewport');
  viewport.setAttribute('content', 'width=device-width, maximum-scale=1.0, user-scalable=no');
  return headTag.appendChild(viewport);
};

convertAttachmentTags = function() {
  var attachment, attachmentObj, attachments, dbAttachments, endIdIndex, filename, fn, i, id, images, j, ref, ref1, size, src, startIdIndex, url;
  attachments = document.getElementsByTagName('mailbox-attach');
  images = document.getElementsByTagName('mailbox-img');
  dbAttachments = document.getElementsByClassName('mb-db-attachment-link');
  fn = function(attachmentObj) {
    var buttondiv;
    buttondiv = attachmentObj.attachmentDiv.getElementsByClassName('mbx-button')[0];
    attachmentObj.attachmentDiv.addEventListener('click', function(evt) {
      return attachmentClickHandler(evt, attachmentObj, 'select');
    }, false);
    attachmentObj.attachmentDiv.addEventListener('dblclick', function(evt) {
      return attachmentClickHandler(evt, attachmentObj, 'open');
    }, false);
    attachmentObj.attachmentDiv.addEventListener('dragstart', function(evt) {
      return attachmentDragHandler(evt, attachmentObj);
    }, false);
    attachmentObj.attachmentDiv.addEventListener('dragend', function(evt) {
      return attachmentDragEndHandler(evt, attachmentObj);
    }, false);
    return buttondiv.addEventListener('click', function(evt) {
      return attachmentClickHandler(evt, attachmentObj, 'save');
    }, false);
  };
  for (i = j = 0, ref1 = attachments.length + images.length + dbAttachments.length; j < ref1; i = j += 1) {
    attachment = null;
    id = null;
    if (i < attachments.length) {
      attachment = attachments[i];
      src = attachment.getAttribute('src');
      id = src.substring(src.lastIndexOf('/') + 1);
    } else if (i < attachments.length + images.length) {
      attachment = images[i - attachments.length];
      src = attachment.getAttribute('src');
      id = src.substring(src.lastIndexOf('/') + 1);
    } else {
      attachment = dbAttachments[i - (attachments.length + images.length)];
      attachment.setAttribute('onclick', 'return false;');
      attachment.parentNode.removeChild(attachment.nextSibling);
      filename = attachment.getAttribute('data-filename');
      size = parseInt(attachment.getAttribute('data-size'));
      attachment.setAttribute('filename', filename);
      attachment.setAttribute('size', size);
      attachment.setAttribute('mime', '');
      url = attachment.getAttribute('data-url');
      endIdIndex = url.lastIndexOf('/');
      startIdIndex = url.substring(0, endIdIndex).lastIndexOf('/') + 1;
      src = null;
      id = url.substring(startIdIndex, endIdIndex);
      if (size > sizeLimit) {
        src = "mailbox://dropbox_link/" + globalAccountID + "/" + globalEmailID + "/" + id + "/" + filename;
      } else {
        src = "mailbox://dropbox_download/" + globalAccountID + "/" + globalEmailID + "/" + id;
      }
      attachment.setAttribute('href', '#');
      attachment.setAttribute('src', src);
    }
    ref = "mailbox-att" + id;
    attachmentObj = new Attachments(attachment);
    if (atts[ref] == null) {
      atts[ref] = [];
    }
    atts[ref].push(attachmentObj);
    fn(attachmentObj);
    attachment.innerHTML = "";
    attachment.appendChild(attachmentObj.attachmentDiv);
    if (attachmentObj.mbURL !== void 0) {
      Attachments.linkHelper(attachmentObj.mailboxURLAction('check_download'));
    }
  }
  window.onkeydown = function(evt) {
    return keydownHandler(evt);
  };
  window.onkeyup = function(evt) {
    return keyupHandler(evt);
  };
  return document.addEventListener('click', function(evt) {
    return attachmentClickHandler(evt, null, 'deselect');
  }, false);
};

attachmentDragHandler = function(evt, attachmentObj) {
  if (!attachmentObj.hasDownloaded && !attachmentObj.inProgress) {
    downloadAttachment(attachmentObj);
    return;
  }
  return evt.dataTransfer.effectAllowed = 'copy';
};

attachmentDragEndHandler = function(evt, attachmentObj) {
  return true;
};

attachmentClickHandler = function(evt, attachmentObj, action) {
  if (action === 'deselect') {
    activeAttachment = null;
    Attachments.deselectAll();
    return;
  }
  if (!attachmentObj.hasDownloaded && !attachmentObj.inProgress) {
    downloadAttachment(attachmentObj);
    return;
  }
  if (action === 'select') {
    Attachments.deselectAll();
    attachmentObj.select();
    activeAttachment = attachmentObj;
  } else if (action === 'open') {
    Attachments.linkHelper(attachmentObj.mailboxURLAction('open_file'));
  } else if (action === 'save') {
    if (attachmentObj.hasDownloaded) {
      Attachments.linkHelper(attachmentObj.mailboxURLAction('save'));
    }
  }
  evt.preventDefault();
  return evt.stopPropagation();
};

keydownHandler = function(evt) {
  if (activeAttachment && evt.keyCode === 32) {
    return false;
  }
  return true;
};

keyupHandler = function(evt) {
  var active;
  if (activeAttachment && evt.keyCode === 32) {
    active = document.querySelector('.mbx-active');
    if (active) {
      Attachments.linkHelper(activeAttachment.mailboxURLAction('preview'));
      evt.preventDefault();
      return evt.stopPropagation();
    }
  }
};

updateDownloadState = function(att_id, raw_value) {
  var attachments, i, j, ref, ref1, results;
  ref = 'mailbox-att' + att_id;
  attachments = atts[ref];
  results = [];
  for (i = j = 0, ref1 = attachments.length; 0 <= ref1 ? j < ref1 : j > ref1; i = 0 <= ref1 ? ++j : --j) {
    results.push((function() {
      var attachmentObj;
      attachmentObj = attachments[i];
      return attachmentObj.updateDownloadState(raw_value);
    })());
  }
  return results;
};

resetDownloadForAttachment = function(att_id) {
  var attachments, i, j, ref, ref1, results;
  ref = "mailbox-att" + att_id;
  attachments = atts[ref];
  results = [];
  for (i = j = 0, ref1 = attachments.length; 0 <= ref1 ? j < ref1 : j > ref1; i = 0 <= ref1 ? ++j : --j) {
    results.push((function() {
      var attachmentObj;
      attachmentObj = attachments[i];
      return attachmentObj.resetDownloadState();
    })());
  }
  return results;
};

failedDownloadForAttachment = function(att_id) {
  var attachments, i, j, ref, ref1, results;
  ref = 'mailbox-att' + att_id;
  attachments = atts[ref];
  results = [];
  for (i = j = 0, ref1 = attachments.length; 0 <= ref1 ? j < ref1 : j > ref1; i = 0 <= ref1 ? ++j : --j) {
    results.push((function() {
      var attachmentObj, delay, retry;
      attachmentObj = attachments[i];
      if (attachmentObj.redownloadAttempts > 0 && attachmentObj.redownloadRetryCount <= attachmentObj.redownloadAttempts) {
        attachmentObj.redownloadRetryCount++;
        retry = function(obj) {
          return function() {
            obj.resetDownloadState();
            return downloadAttachments(obj);
          };
        };
        delay = attachmentObj.redownloadDelay * attachmentObj.redownloadRetryCount;
        return setTimeout(retry(attachmentObj), delay);
      } else {
        return attachmentObj.downloadFailed();
      }
    })());
  }
  return results;
};

urlForAttachment = function(att_id) {
  var attachment, ref;
  ref = 'mailbox-att' + att_id;
  attachment = atts[ref][0];
  if (attachment.attachmentDiv.parentNode.tagName === "A") {
    return attachment.attachmentDiv.parentNode.getAttribute("data-url");
  }
  return "";
};

finishDownloading = function(att_id, file_url) {
  var attachments, i, j, ref, ref1, results;
  ref = "mailbox-att" + att_id;
  attachments = atts[ref];
  file_url = file_url.split('/').map(function(part) {
    return encodeURIComponent(part);
  }).join('/');
  results = [];
  for (i = j = 0, ref1 = attachments.length; 0 <= ref1 ? j < ref1 : j > ref1; i = 0 <= ref1 ? ++j : --j) {
    results.push((function() {
      var attachmentObj;
      attachmentObj = attachments[i];
      attachmentObj.downloadDone(att_id, file_url, null, true);
      return self.invalidateContentHeight();
    })());
  }
  return results;
};

downloadAttachment = function(attachmentObj) {
  var isImage, ref1;
  isImage = (ref1 = attachmentObj.isInlineOrAttachedImage()) != null ? ref1 : {
    1: 0
  };
  return Attachments.linkHelper(attachmentObj.mbURL + "/" + isImage);
};

autoDownloadAttachments = function(size_limit) {
  var attachments, i, key, limitSize, results, value;
  limitSize = parseInt(size_limit);
  results = [];
  for (key in atts) {
    value = atts[key];
    attachments = atts[key];
    results.push((function() {
      var j, ref1, results1;
      results1 = [];
      for (i = j = 0, ref1 = attachments.length; 0 <= ref1 ? j < ref1 : j > ref1; i = 0 <= ref1 ? ++j : --j) {
        results1.push((function() {
          var attachmentObj, attachmentSize;
          attachmentObj = attachments[i];
          attachmentSize = parseInt(attachmentObj.filesize);
          if (attachmentSize <= limitSize && !attachmentObj.isDownloaded) {
            return downloadAttachment(attachmentObj);
          }
        })());
      }
      return results1;
    })());
  }
  return results;
};

lastContentHeight = 0;

invalidateContentHeight = function(force) {
  updateContentHeight(force);
  return window.requestAnimationFrame(function(step) {
    return window.requestAnimationFrame(function(step) {
      return updateContentHeight(force);
    });
  });
};

updateContentHeight = function(force) {
  var rect;
  rect = document.body.getBoundingClientRect();
  if (rect.height !== lastContentHeight || force) {
    lastContentHeight = Math.round(rect.height + rect.top);
    if (window.cell !== void 0) {
      return window.cell.contentHeightDidChange(lastContentHeight);
    }
  }
};

handleShowMore = function(e) {
  var ref1;
  if (typeof this !== "undefined" && this !== null) {
    if ((ref1 = this.style) != null) {
      ref1.display = 'none';
    }
  }
  loadingdiv(true);
  if (typeof bridge !== "undefined" && bridge !== null) {
    if (typeof bridge.handleShowMore === "function") {
      bridge.handleShowMore();
    }
  }
  e.preventDefault();
  return e.stopPropagation();
};

insertFullBody = function(data) {
  var e, error, forceReload, loadingDiv, parsedData, ref1, showMoreDiv;
  loadingdiv(false);
  if ((data != null)) {
    try {
      parsedData = JSON.parse(data);
    } catch (error) {
      e = error;
      return;
    }
    if ((parsedData != null)) {
      showMoreDiv = document.getElementById('show-more');
    }
    if ((showMoreDiv != null)) {
      showMoreDiv.parentNode.removeChild(showMoreDiv);
      loadingDiv = document.getElementById('mbx-loading');
      if ((loadingDiv != null)) {
        loadingDiv.parentNode.removeChild(loadingDiv);
      }
      if ((ref1 = document.getElementById('mbx-content')) != null) {
        ref1.innerHTML = parsedData['body'];
      }
      document.body.style.overflowX = 'auto';
      document.body.style.overflowY = 'hidden';
      document.body.style.padding = "0px 10px 10px 10px";
      forceReload = document.createElement('img');
      forceReload.setAttribute('src', 'data:image/png;base64,');
      forceReload = null;
      return invalidateContentHeight(false);
    }
  }
};

resetShowMore = function() {
  var showMoreDiv;
  loadingdiv(false);
  showMoreDiv = document.getElementById('show-more');
  if ((showMoreDiv != null)) {
    showMoreDiv.style.display = 'block';
  }
  return this;
};

loadingdiv = function(display) {
  var displayProperty, loadingDiv;
  if (display == null) {
    display = false;
  }
  loadingDiv = document.getElementById('mbx-loading');
  if ((loadingDiv != null)) {
    displayProperty = display === true ? "block" : "none";
    loadingDiv.style.display = displayProperty;
  }
  return this;
};


/*
 * Create the attachment divs when the document is ready.
 */

document.addEventListener('DOMContentLoaded', docReady = function() {
  var showMoreDiv;
  document.removeEventListener('DOMContentLoaded', docReady);
  convertAttachmentTags();
  showMoreDiv = document.getElementById('show-more');
  if ((showMoreDiv != null)) {
    return showMoreDiv.addEventListener('click', handleShowMore, false);
  }
});
